package com.example.pda.ui

import android.util.Log
import androidx.compose.foundation.layout.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.KeyboardArrowLeft
import androidx.compose.material.icons.filled.KeyboardArrowRight
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import com.example.pda.model.loginItem
import androidx.compose.ui.res.stringResource
import com.example.pda.R
import com.example.pda.model.AppPrefs
import com.example.pda.model.successItem
import com.example.pda.network.HttpClient
import com.example.pda.network.NetworkHelper


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun LoginScreen(
    onSetScreen: () -> Unit,
    onMainScreen: () -> Unit
) {
    var username by remember { mutableStateOf("") }
    var password by remember { mutableStateOf("") }
    var showPassword by remember { mutableStateOf(false) }
    var useritem = loginItem(username = username, password = password)




    var loginStatus by remember { mutableStateOf<Boolean?>(null) }

    // 监听登录状态变化
    LaunchedEffect(loginStatus) {
        loginStatus?.takeIf { it }?.let {
            onMainScreen() // 状态为true时跳转
            // 在登录成功后调用
            HttpClient.token = AppPrefs.token
        }

    }

    Scaffold(

        topBar = {
            TopAppBar(
                title = {
                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Icon(
                            painter = painterResource(id = R.drawable.logo),
                            contentDescription = "PDA Logo",
                            modifier = Modifier.size(40.dp),
                            tint = MaterialTheme.colorScheme.surfaceTint
                        )
                        Spacer(Modifier.width(8.dp))
                        Text("信泰PDA扫描系统")
                    }
                },
                actions = {
                    IconButton(onClick = { onSetScreen() }) {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_settings),
                            contentDescription = "Settings",
                            tint = MaterialTheme.colorScheme.onSurface
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = Color(0xFFBCD0C5), // 自定义颜色
                    titleContentColor = MaterialTheme.colorScheme.onPrimary,
                    actionIconContentColor = MaterialTheme.colorScheme.onPrimary
                )
                
            )

        }
    ) { padding ->
        Column(
            modifier = Modifier
                .padding(padding)
                .fillMaxSize(),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            OutlinedTextField(
                value = username,
                onValueChange = { username = it },
                label = { Text(stringResource(id = R.string.username_label)) },
                modifier = Modifier.width(280.dp)
            )
            Spacer(modifier = Modifier.height(16.dp))
            OutlinedTextField(
                value = password,
                onValueChange = { password = it },
                label = { Text(stringResource(id = R.string.password_label)) },
                visualTransformation = if (showPassword) VisualTransformation.None else PasswordVisualTransformation(),
                trailingIcon = {
                    val image = if (showPassword) Icons.Default.KeyboardArrowRight else Icons.Default.KeyboardArrowLeft
                    IconButton(onClick = { showPassword = !showPassword }) {
                        Icon(imageVector = image, contentDescription = null)
                    }
                },
                modifier = Modifier.width(280.dp)
            )
            Spacer(modifier = Modifier.height(16.dp))
            Button(
                onClick = {
                    useritem.username=username
                    useritem.password=password
                    onlogin (useritem){ success ->
                        loginStatus = success // 回调中更新状态
                    }
                     },
                modifier = Modifier.width(280.dp) ,
                 colors = ButtonDefaults.buttonColors(
                             containerColor = Color(0xFF91BFBF)
                             )
            ) {
                Text(stringResource(id = R.string.login_button))
            }
        }
    }
}

private fun onlogin(
    useritem: loginItem,
    onResult: (Boolean) -> Unit // 新增结果回调
) {
    NetworkHelper.userlogin(
        data = useritem,
        onSuccess = { successItem ->
            AppPrefs.token = successItem.openid
            AppPrefs.username = successItem.name
            AppPrefs.userappid = successItem.appid
            AppPrefs.stafftype = successItem.staff_type
            AppPrefs.islogin = true
            onResult(true) // 传递成功状态
        },
        onError = { msg ->
            Log.e("login", msg)
            AppPrefs.islogin = false
            onResult(false) // 传递失败状态
        }
    )
}
