package com.example.pda.ui

import androidx.compose.foundation.layout.*
import androidx.compose.material3.SnackbarHostState
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material3.Scaffold
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Modifier
import androidx.compose.ui.Alignment

import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import com.example.pda.ui.viewmodel.PingViewmodel
import kotlinx.coroutines.launch
import com.example.pda.model.AppPrefs

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PingScreen(onMainScreen: () -> Unit) {
    val viewModel: PingViewmodel = viewModel()
    val uiState = viewModel.uiState.collectAsState()
    val snackbarHostState = remember { SnackbarHostState() }
    val coroutineScope = rememberCoroutineScope()
    val inputIp = remember {
        mutableStateOf(AppPrefs.ip_server.ifEmpty { "192.168.1.1" })
    }

    LaunchedEffect(uiState.value) {
        when (val currentState = uiState.value) {
            is PingViewmodel.UiState.Success -> {
                coroutineScope.launch {
                    snackbarHostState.showSnackbar(currentState.message)
                    viewModel.resetState()
                }
            }
            is PingViewmodel.UiState.Error -> {
                coroutineScope.launch {
                    snackbarHostState.showSnackbar("错误：${currentState.message}")
                    viewModel.resetState()
                }
            }
            else -> {}
        }
    }

    Scaffold(
        snackbarHost = { SnackbarHost(snackbarHostState) },
        topBar = {
            TopAppBar(
                title = { Text("扫描结果详情") },
                navigationIcon = {
                    IconButton(onClick = onMainScreen) {
                        Icon(Icons.Default.ArrowBack, "主页")
                    }
                }
            )
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
                .padding(24.dp)
        ) {
            // 新增输入框
            TextField(
                value = inputIp.value,
                onValueChange = { inputIp.value = it },
                label = { Text("输入IP地址") },
                modifier = Modifier.fillMaxWidth()
            )

            Spacer(Modifier.height(16.dp))

            Text("扫描结果：", style = MaterialTheme.typography.titleLarge)
            Spacer(Modifier.height(16.dp))
            Card(Modifier.fillMaxWidth()) {
                Text(
                    text = "正在检测：${inputIp.value}",  // 显示输入内容
                    modifier = Modifier.padding(16.dp),
                    style = MaterialTheme.typography.bodyLarge,
                    overflow = TextOverflow.Ellipsis,
                    maxLines = 5
                )
            }
            ExtendedFloatingActionButton(
                modifier = Modifier
                    .align(Alignment.CenterHorizontally) // 修正对齐方式
                    .padding(top = 16.dp),
                
                onClick = { viewModel.ping(inputIp.value);AppPrefs.ip_server=inputIp.value.toString() } // 使用输入值
            ) { Text("Ping测试") }
        }
    }
}